<?php

namespace Teknisa\DF\Factories;
use Doctrine\ORM\EntityManager;

class Ger57000TabelaDoSimplesNacionalFactory {
    protected $entityManager;
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection    = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    
    public function deleteTabelaDeReferencia($tabela) {
       $params = array(
            "P_CDSIMPLESNAC" => $tabela
        );
        
        $sql = "DELETE FROM SIMPLESNACIONAL WHERE CDSIMPLESNACIONAL = :P_CDSIMPLESNAC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    public function deleteTipoOperacSimples($tabela) {
       $params = array(
            "P_CDSIMPLESNAC" => $tabela
        );
        
        $sql = "DELETE FROM TPOPERSIMPLESNAC WHERE CDSIMPLESNACIONAL = :P_CDSIMPLESNAC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    public function deleteCfopSimples($tabela) {
        $params = array(
            "P_CDSIMPLESNAC" => $tabela
        );
        
        $sql = "DELETE FROM CFOPSIMPLESNAC WHERE CDSIMPLESNACIONAL = :P_CDSIMPLESNAC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    public function deleteAllFaixa($tabela) {
        $params = array(
            "P_CDSIMPLESNAC" => $tabela
        );
        
        $sql = "DELETE FROM FAIXASIMPLESNAC WHERE CDSIMPLESNACIONAL = :P_CDSIMPLESNAC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    public function deleteAllImpostosFaixa($tabela) {
        $params = array(
            "P_CDSIMPLESNAC" => $tabela
        );
        
        $sql = "DELETE FROM IMPSIMPLESFAIXA WHERE CDSIMPLESNACIONAL = :P_CDSIMPLESNAC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }

    public function getPrxFaixa($cdsimples) {
       
            
        $sql = <<<SQL
        SELECT LPAD(NVL(MAX(CDFAIXA), '0')+1, 5, '0') PRX_FAIXA
        FROM FAIXASIMPLESNAC
        WHERE CDSIMPLESNACIONAL = :P_CDSIMPLESNAC
SQL;
        

        $params = array(
            "P_CDSIMPLESNAC" => $cdsimples
        );
        
                            
        $std = $this->entityManager->getConnection()->fetchAll($sql, $params);  
        
        
        return $this->entityManager->getConnection()->fetchAll($sql, $params);      

    }
    
    public function deleteImpostosFaixa($cdfaixa, $cdsimplesnacional) {
        $params = array(
            "CDFAIXA"           => $cdfaixa,
            "CDSIMPLESNACIONAL" => $cdsimplesnacional
        );
        
        $sql = "DELETE FROM IMPSIMPLESFAIXA WHERE CDSIMPLESNACIONAL = :CDSIMPLESNACIONAL AND CDFAIXA = :CDFAIXA";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteFaixa($cdfaixa, $cdsimplesnacional) {
        $params = array(
            "CDFAIXA"           => $cdfaixa,
            "CDSIMPLESNACIONAL" => $cdsimplesnacional
        );
        
        $sql = "DELETE FROM FAIXASIMPLESNAC WHERE CDSIMPLESNACIONAL = :CDSIMPLESNACIONAL AND CDFAIXA = :CDFAIXA";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    } 
    
    public function validaIntervaloCfop($dtinivalid, $dtfimvalid, $cdsimplesnac, $cdcfop){
        $params = array(
            "P_DTINIVALID"   => $dtinivalid,
            "P_DTFIMVALID"   => $dtfimvalid,
            "P_CDSIMPLESNAC" => $cdsimplesnac,
            "P_CDCFOP"       => $cdcfop
            
        );
        
        $sql = "SELECT MAX(DSCFOPPADRAO) AS DSCFOPPADRAO FROM( /*Dados cadastrados para uma data de vigência maior que a atual*/ SELECT C.CDSIMPLESNACIONAL, C.CDCFOPPADRAO, CASE WHEN :P_DTFIMVALID IS NULL THEN 'DtFim_CFOP_Inf' WHEN :P_DTFIMVALID >= S.DTINIVIGENCIA THEN 'DtInt_CFOP_Inv' ELSE '' END AS DSCFOPPADRAO FROM SIMPLESNACIONAL S, CFOPSIMPLESNAC C WHERE C.CDCFOPPADRAO = :P_CDCFOP AND C.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND C.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA > :P_DTINIVALID UNION ALL /*Dados cadastrados para uma data de vigência menor que a atual*/ SELECT C.CDSIMPLESNACIONAL, C.CDCFOPPADRAO, CASE WHEN S.DTFIMVIGENCIA IS NULL THEN 'DtFimOld_CFOP_Inf' WHEN S.DTFIMVIGENCIA >= :P_DTINIVALID THEN 'DtInt_CFOP_Inv' ELSE '' END AS DSCFOPPADRAO FROM SIMPLESNACIONAL S, CFOPSIMPLESNAC C WHERE C.CDCFOPPADRAO = :P_CDCFOP AND C.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND C.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA < :P_DTINIVALID UNION ALL /*Dados cadastrados para a mesma data de vigência*/ SELECT C.CDSIMPLESNACIONAL, C.CDCFOPPADRAO, 'DtInt_CFOP_Inv' AS DSCFOPPADRAO FROM SIMPLESNACIONAL S, CFOPSIMPLESNAC C WHERE C.CDCFOPPADRAO = :P_CDCFOP AND C.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND C.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA = :P_DTINIVALID)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function validaIntervaloTipoOperacao($dtinivalid, $dtfimvalid, $cdsimplesnac, $cdtipooper){
        $params = array(
            "P_DTINIVALID"   => $dtinivalid,
            "P_DTFIMVALID"   => $dtfimvalid,
            "P_CDSIMPLESNAC" => $cdsimplesnac,
            "P_CDTIPOOPER"   => $cdtipooper
        );
        
        $sql = "SELECT MAX(NMTIPOOPER) AS NMTIPOOPER FROM( /*Dados cadastrados para uma data de vigência maior que a atual*/ SELECT T.CDSIMPLESNACIONAL, T.CDTIPOOPER, T.IDENTRSAIDOP, CASE WHEN :P_DTFIMVALID IS NULL THEN 'DtFim_OPER_Inf' WHEN :P_DTFIMVALID >= S.DTINIVIGENCIA THEN 'DtInt_OPER_Inv' ELSE '' END AS NMTIPOOPER FROM SIMPLESNACIONAL S, TPOPERSIMPLESNAC T WHERE T.CDTIPOOPER = :P_CDTIPOOPER AND T.IDENTRSAIDOP = 'S' AND T.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND T.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA > :P_DTINIVALID AND T.IDTIPOOPERTAB = 'S' UNION ALL /*Dados cadastrados para uma data de vigência menor que a atual*/ SELECT T.CDSIMPLESNACIONAL, T.CDTIPOOPER, T.IDENTRSAIDOP, CASE WHEN S.DTFIMVIGENCIA IS NULL THEN 'DtFimOld_OPER_Inf' WHEN S.DTFIMVIGENCIA >= :P_DTINIVALID THEN 'DtInt_OPER_Inv' ELSE '' END AS NMTIPOOPER FROM SIMPLESNACIONAL S, TPOPERSIMPLESNAC T WHERE T.CDTIPOOPER = :P_CDTIPOOPER AND T.IDENTRSAIDOP = 'S' AND T.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND T.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA < :P_DTINIVALID AND T.IDTIPOOPERTAB = 'S' UNION ALL /*Dados cadastrados para a mesma data de vigência*/ SELECT T.CDSIMPLESNACIONAL, T.CDTIPOOPER, T.IDENTRSAIDOP, 'DtInt_OPER_Inv' AS NMTIPOOPER FROM SIMPLESNACIONAL S, TPOPERSIMPLESNAC T WHERE T.CDTIPOOPER = :P_CDTIPOOPER AND T.IDENTRSAIDOP = 'S' AND T.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND T.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA = :P_DTINIVALID AND T.IDTIPOOPERTAB = 'S')";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function validaEdicaoTabelaSimplesNacional($dtinivalid, $dtfimvalid, $cdsimplesnac){
        $params = array(
            "P_DTINIVALID"   => $dtinivalid,
            "P_DTFIMVALID"   => $dtfimvalid,
            "P_CDSIMPLESNAC" => $cdsimplesnac
        );
        
        $sql = "SELECT MAX(DSERRO) AS DSERRO FROM( /*Dados cadastrados para uma data de vigência maior que a atual*/ SELECT CASE WHEN :P_DTFIMVALID IS NULL THEN 'DtFim_CFOP_Inf' WHEN :P_DTFIMVALID >= S.DTINIVIGENCIA THEN 'DtInt_CFOP_Inv' ELSE '' END AS DSERRO FROM SIMPLESNACIONAL S, CFOPSIMPLESNAC C, CFOPSIMPLESNAC A WHERE C.CDCFOPPADRAO = A.CDCFOPPADRAO AND C.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND C.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA > :P_DTINIVALID AND A.CDSIMPLESNACIONAL = :P_CDSIMPLESNAC UNION ALL /*Dados cadastrados para uma data de vigência menor que a atual*/ SELECT CASE WHEN S.DTFIMVIGENCIA IS NULL THEN 'DtFimOld_CFOP_Inf' WHEN S.DTFIMVIGENCIA >= :P_DTINIVALID THEN 'DtInt_CFOP_Inv' ELSE '' END AS DSERRO FROM SIMPLESNACIONAL S, CFOPSIMPLESNAC C, CFOPSIMPLESNAC A WHERE C.CDCFOPPADRAO = A.CDCFOPPADRAO AND C.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND C.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA < :P_DTINIVALID AND A.CDSIMPLESNACIONAL = :P_CDSIMPLESNAC UNION ALL /*Dados cadastrados para a mesma data de vigência*/ SELECT 'DtInt_CFOP_Inv' AS DSERRO FROM SIMPLESNACIONAL S, CFOPSIMPLESNAC C, CFOPSIMPLESNAC A WHERE C.CDCFOPPADRAO = A.CDCFOPPADRAO AND C.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND C.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA = :P_DTINIVALID AND A.CDSIMPLESNACIONAL = :P_CDSIMPLESNAC UNION ALL SELECT CASE WHEN :P_DTFIMVALID IS NULL THEN 'DtFim_OPER_Inf' WHEN :P_DTFIMVALID >= S.DTINIVIGENCIA THEN 'DtInt_OPER_Inv' ELSE '' END AS DSERRO FROM SIMPLESNACIONAL S, TPOPERSIMPLESNAC T, TPOPERSIMPLESNAC A WHERE T.CDTIPOOPER = A.CDTIPOOPER AND T.IDENTRSAIDOP = A.IDENTRSAIDOP AND T.IDTIPOOPERTAB = 'S' AND T.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND T.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA > :P_DTINIVALID AND A.CDSIMPLESNACIONAL = :P_CDSIMPLESNAC AND A.IDENTRSAIDOP = 'S' AND A.IDTIPOOPERTAB = 'S' UNION ALL /*Dados cadastrados para uma data de vigência menor que a atual*/ SELECT CASE WHEN S.DTFIMVIGENCIA IS NULL THEN 'DtFimOld_OPER_Inf' WHEN S.DTFIMVIGENCIA >= :P_DTINIVALID THEN 'DtInt_OPER_Inv' ELSE '' END AS DSERRO FROM SIMPLESNACIONAL S, TPOPERSIMPLESNAC T, TPOPERSIMPLESNAC A WHERE T.CDTIPOOPER = A.CDTIPOOPER AND T.IDENTRSAIDOP = A.IDENTRSAIDOP AND T.IDTIPOOPERTAB = 'S' AND T.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND T.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA < :P_DTINIVALID AND A.CDSIMPLESNACIONAL = :P_CDSIMPLESNAC AND A.IDENTRSAIDOP = 'S' AND A.IDTIPOOPERTAB = 'S' UNION ALL /*Dados cadastrados para a mesma data de vigência*/ SELECT 'DtInt_OPER_Inv' AS DSERRO FROM SIMPLESNACIONAL S, TPOPERSIMPLESNAC T, TPOPERSIMPLESNAC A WHERE T.CDTIPOOPER = A.CDTIPOOPER AND T.IDENTRSAIDOP = A.IDENTRSAIDOP AND T.IDTIPOOPERTAB = 'S' AND T.CDSIMPLESNACIONAL <> :P_CDSIMPLESNAC AND T.CDSIMPLESNACIONAL = S.CDSIMPLESNACIONAL AND S.DTINIVIGENCIA = :P_DTINIVALID AND A.CDSIMPLESNACIONAL = :P_CDSIMPLESNAC AND A.IDENTRSAIDOP = 'S' AND A.IDTIPOOPERTAB = 'S') ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getTabelasSimplesNacioanl($cdsimplesnacional){
        $params = array(
            "CDSIMPLESNACIONAL"   => $cdsimplesnacional
        );
        
        $sql = "SELECT * FROM SIMPLESNACIONAL WHERE CDSIMPLESNACIONAL = :CDSIMPLESNACIONAL ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

    
}