<?php
namespace Teknisa\DF\Modules\Relatorios\Factories;

use Teknisa\Libs\Util\DateUtil;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Adm03000ReDeNotasFiscais{
    protected $connection;
    protected $entityManager;

    public function __construct($entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    // gerais
    public function verificaNumeracaoRe($cdfilial, $nrorg){
        $sql = "SELECT CDCONTADOR,
                    SUBSTR(NRSEQUENCIAL,LENGTH(NRSEQUENCIAL)-3,4) AS NRSEQUENCIAL,
                    NRSEQUENCIAL AS NRSEQREAL
                FROM NOVOCODIGO
                WHERE CDCONTADOR = 'RENOTAFISCAL'|| :CDFILIAL
                    AND NRORG = :NRORG";

        $params = array("CDFILIAL"=>$cdfilial,
                        "NRORG"=>$nrorg);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }

    public function reDataInformada($cdfilial, $datare, $identrsaid, $nrorg){
        $sql = "SELECT CDFILIAL
                FROM NUMERORNF
                WHERE CDFILIAL     = :CDFILIAL
                  AND DTNUMERNF    = :DATARE
                  AND IDENTRSAID   = :IDENTRSAID
                  AND IDTIPOOPERNF = :IDENTRSAID
                  AND NRORG = :NRORG";
        $params = array("CDFILIAL"=>$cdfilial,
                        "DATARE"=>$datare,
                        "IDENTRSAID"=>$identrsaid,
                        "NRORG"=>$nrorg);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }

    public function reDataPosterior($cdfilial, $datare, $identrsaid, $nrorg){
        $sql = "SELECT CDFILIAL
                FROM NUMERORNF
                WHERE CDFILIAL     = :CDFILIAL
                  AND DTNUMERNF    > :DATARE
                  AND IDENTRSAID   = :IDENTRSAID
                  AND IDTIPOOPERNF = :IDENTRSAID
                  AND NRORG = :NRORG";
        $params = array("CDFILIAL"=>$cdfilial,
                        "DATARE"=>$datare,
                        "IDENTRSAID"=>$identrsaid,
                        "NRORG"=>$nrorg);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }

    public function ferivicaReAnoCor($cdfilial, $dataantre, $dtanterior, $nrorg){
        $sql = "SELECT CDFILIAL
                       FROM NUMERORNF
                      WHERE CDFILIAL     = :CDFILIAL
                        AND DTNUMERNF   <= :DATAANTRE
                        AND DTNUMERNF   >= :DTANTERIOR
                        AND NRORG = :NRORG";
        $params = array("CDFILIAL"=>$cdfilial,
                        "DATAANTRE"=>$dataantre,
                        "DTANTERIOR"=>$dtanterior,
                        "NRORG"=>$nrorg);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }

    public function ferivicaRe($cdfilial, $identrsaid, $dtnumernf, $nrorg){
        $sql = "SELECT CDFILIAL
                FROM NUMERORNF
                WHERE CDFILIAL     = :CDFILIAL
                  AND IDENTRSAID   = :IDENTRSAID
                  AND IDTIPOOPERNF = :IDENTRSAID
                  AND DTNUMERNF    = :DTNUMERNF
                  AND NRORG = :NRORG";
        $params = array("CDFILIAL"=>$cdfilial,
                        "IDENTRSAID"=>$identrsaid,
                        "DTNUMERNF"=>$dtnumernf,
                        "NRORG"=>$nrorg);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }

    //não centraliza
    public function verificaCapaDocumentoNaoCentralia($cdalmoxarife, $datare, $cdlocalestoq, $cdfilial, $identrsaid, $nrorg){
        $sql = "SELECT DISTINCT N.CDALMOXARIFE, N.CDLOCALESTOQ, A.DSALMOXARIFE, L.DSLOCALESTOQ
                FROM NOTAFISCAL N, CONTAPAGAR C, ALMOXARIFADO A, LOCALESTOQUE L, TIPOOPERAC T
                WHERE N.CDFILIRECE           = :CDFILIAL
                    AND N.NRORG = :NRORG
                    AND N.IDENTRSAIDOP           = 'E'
                    AND :IDENTRSAID           <> 'S'
                    AND N.DTENTRSAID             = :DATARE
                    AND NVL(T.IDCOMPEMISRE, 'F') = 'F'
                    AND ((N.IDSISTEMA           IN ('EST','DFE')
                    OR IDSISTEMA                IS NULL))
                    AND N.CDFILIAL               = C.CDFILIAL(+)
                    AND N.NRLANCTONF             = C.NRLANCTONF(+)
                    AND N.NRORG = C.NRORG(+)
                    AND N.IDENTRSAIDOP           = T.IDENTRSAIDOP
                    AND N.CDTIPOOPER             = T.CDTIPOOPER
                    AND N.NRORG = T.NRORG
                    AND ((N.CDALMOXARIFE         = NVL(:CDALMOXARIFE, N.CDALMOXARIFE))
                    OR :CDALMOXARIFE           = 'T')
                    AND ((N.CDLOCALESTOQ         = NVL(:CDLOCALESTOQ, N.CDLOCALESTOQ))
                    OR :CDLOCALESTOQ           = 'T')
                    AND N.CDALMOXARIFE           = A.CDALMOXARIFE(+)
                    AND N.CDFILIAL               = A.CDFILIAL(+)
                    AND N.NRORG = A.NRORG(+)
                    AND N.CDALMOXARIFE           = L.CDALMOXARIFE(+)
                    AND N.CDFILIAL               = L.CDFILIAL(+)
                    AND N.CDLOCALESTOQ           = L.CDLOCALESTOQ(+)
                    AND N.NRORG = L.NRORG(+)
                    GROUP BY N.CDALMOXARIFE, N.CDLOCALESTOQ, A.DSALMOXARIFE, L.DSLOCALESTOQ
                UNION ALL
                SELECT DISTINCT '' AS CDALMOXARIFE, '' AS CDLOCALESTOQ, '' AS DSALMOXARIFE , '' AS DSLOCALESTO
                FROM NOTAFISCAL N, TIPOOPERAC T
                WHERE N.CDFILIEMIT           = :CDFILIAL
                    AND N.NRORG = :NRORG
                    AND N.IDENTRSAIDOP           = 'S'
                    AND :IDENTRSAID           <> 'E'
                    AND N.DTENTRSAID             = :DATARE
                    AND IDSTATUS                <> 'C'
                    AND N.IDENTRSAIDOP           = T.IDENTRSAIDOP
                    AND N.CDTIPOOPER             = T.CDTIPOOPER
                    AND N.NRORG = T.NRORG
                    AND NVL(T.IDCOMPEMISRE, 'F') = 'F'
                    AND ((N.IDGEROUTDOCU        IS NULL)
                    OR (N.IDGEROUTDOCU           = 'A'))
                    AND ((N.IDSISTEMA           IN ('EST','DFS','FAC','FAI','FAS')
                    OR IDSISTEMA                IS NULL))
                    GROUP BY N.CDALMOXARIFE, N.CDLOCALESTOQ";

        $params = array("CDALMOXARIFE"=>$cdalmoxarife,
                        "DATARE"=>$datare,
                        "CDLOCALESTOQ"=>$cdlocalestoq,
                        "CDFILIAL"=>$cdfilial,
                        "IDENTRSAID"=>$identrsaid,
                        "NRORG"=>$nrorg);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    // não centraliza entrada
    public function reAnteSCapaE($cdfilial, $identrsaid, $dataantre, $dtanterior, $nrorg){
        $sql = "SELECT MAX(DTENTRSAID) AS DTNUMERNF
                FROM NOTAFISCAL N,
                    (SELECT IDENTRSAIDOP, CDTIPOOPER, NRORG
                        FROM TIPOOPERAC
                       WHERE IDENTRSAIDOP = :IDENTRSAID
                         AND NVL(IDCOMPEMISRE, 'F') = 'F') T
                WHERE N.CDFILIRECE   = :CDFILIAL
                  AND N.IDENTRSAIDOP = :IDENTRSAID
                  AND N.DTENTRSAID BETWEEN :DTANTERIOR AND :DATAANTRE
                  AND (N.IDSISTEMA IN ('EST','DFE') OR N.IDSISTEMA IS NULL)
                  AND N.CDTIPOOPER NOT IN ('10', '09')
                  AND N.IDENTRSAIDOP = T.IDENTRSAIDOP
                  AND N.CDTIPOOPER   = T.CDTIPOOPER
                  AND N.NRORG = :NRORG
                  AND N.NRORG = T.NRORG";
        $params = array("CDFILIAL"=>$cdfilial,
                        "IDENTRSAID"=>$identrsaid,
                        "DATAANTRE"=>$dataantre,
                        "DTANTERIOR"=>$dtanterior,
                        "NRORG"=>$nrorg);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    // não centraliza saida
    public function reAnteSCapaS($cdfilial, $identrsaid, $dataantre, $dtanterior, $nrorg){
        $sql = "SELECT MAX(DTAPROVACAO) AS DTNUMERNF
                FROM NOTAFISCAL N,
                    (SELECT IDENTRSAIDOP,
                      CDTIPOOPER,
                      NRORG
                    FROM TIPOOPERAC
                    WHERE IDENTRSAIDOP = :IDENTRSAID
                    AND IDCOMPEMISRE   = 'C'
                    ) T,
                    (SELECT CDFILIAL,
                      NRORG
                    FROM FILIAL FL
                    WHERE NVL(CDFILIFISC,FL.CDFILIAL) = :CDFILIAL
                    ) FL
                WHERE N.CDFILIEMIT = FL.CDFILIAL
                  AND N.IDENTRSAIDOP = :IDENTRSAID
                  AND IDSTATUS      IN ('A','E')
                  AND N.DTAPROVACAO BETWEEN :DTANTERIOR AND :DATAANTRE
                  AND ((N.IDSISTEMA IN ('EST','DFS','FAI','PDV')
                  OR N.IDSISTEMA    IS NULL))
                  AND N.IDENTRSAIDOP = T.IDENTRSAIDOP
                  AND N.CDTIPOOPER   = T.CDTIPOOPER
                  AND N.NRORG = :NRORG
                  AND N.NRORG = T.NRORG
                  AND N.NRORG = FL.NRORG";
        $params = array("CDFILIAL"=>$cdfilial,
                        "IDENTRSAID"=>$identrsaid,
                        "DATAANTRE"=>$dataantre,
                        "DTANTERIOR"=>$dtanterior,
                        "NRORG"=>$nrorg);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }

    //centraliza
    public function reAnteSCapaC($cdfilial, $identrsaid, $dataantre, $dtanterior, $nrorg){
        $sql = "SELECT MAX(DTAPROVACAO) AS DTNUMERNF
                FROM NOTAFISCAL N,
                     (SELECT IDENTRSAIDOP,
                       CDTIPOOPER,
                       NRORG
                     FROM TIPOOPERAC
                     WHERE IDENTRSAIDOP = :IDENTRSAID
                     AND IDCOMPEMISRE   = 'C'
                     ) T,
                     (SELECT CDFILIAL,
                       NRORG
                     FROM FILIAL FL
                     WHERE NVL(CDFILIFISC,FL.CDFILIAL) = :CDFILIAL
                     ) FL
                WHERE N.CDFILIEMIT = FL.CDFILIAL
                  AND N.IDENTRSAIDOP = :IDENTRSAID
                  AND IDSTATUS      IN ('A','E')
                  AND N.DTAPROVACAO BETWEEN :DTANTERIOR AND :DATAANTRE
                  AND ((N.IDSISTEMA IN ('EST','DFS','FAI','PDV')
                  OR N.IDSISTEMA    IS NULL))
                  AND N.IDENTRSAIDOP = T.IDENTRSAIDOP
                  AND N.CDTIPOOPER   = T.CDTIPOOPER
                  AND N.NRORG = :NRORG
                  AND N.NRORG = T.NRORG
                  AND N.NRORG = FL.NRORG";
        $params = array("CDFILIAL"=>$cdfilial,
                        "IDENTRSAID"=>$identrsaid,
                        "DATAANTRE"=>$dataantre,
                        "DTANTERIOR"=>$dtanterior,
                        "NRORG"=>$nrorg);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }

    public function verificaCapaDocumentoCentrliza($cdalmoxarife, $datare, $cdlocalestoq, $cdfilial, $nrorg){
        $sql = "SELECT N.CDFILIAL
                FROM NOTAFISCAL N, TIPOOPERAC T, FILIAL F
                WHERE N.NRORG = :NRORG
                  AND T.NRORG = N.NRORG
                  AND F.NRORG = N.NRORG
                  AND (N.IDENTRSAIDOP = 'S')
                  AND (N.DTAPROVACAO    = :DATARE)
                  AND (N.IDSTATUS       = 'E'
                  OR N.IDSTATUS         = 'A')
                  AND ((N.CDALMOXARIFE  = :CDALMOXARIFE
                  AND :CDALMOXARIFE  IS NOT NULL)
                  OR (:CDALMOXARIFE  IS NULL)
                  OR (:CDALMOXARIFE   = 'T'))
                  AND ((N.CDLOCALESTOQ  = :CDLOCALESTOQ
                  AND :CDLOCALESTOQ  IS NOT NULL)
                  OR (:CDLOCALESTOQ  IS NULL)
                  OR (:CDLOCALESTOQ   = 'T'))
                  AND (N.IDENTRSAIDOP   = T.IDENTRSAIDOP)
                  AND (N.CDTIPOOPER     = T.CDTIPOOPER)
                  AND (T.IDCOMPEMISRE   = 'C')
                  AND (N.IDSISTEMA      = 'EST'
                  OR N.IDSISTEMA        = 'DFS'
                  OR N.IDSISTEMA        = 'FAI'
                  OR N.IDSISTEMA        = 'PDV'
                  OR N.IDSISTEMA       IS NULL)
                  AND (F.CDFILIFISC     = :CDFILIAL
                  AND F.CDFILIFISC     IS NOT NULL
                  OR F.CDFILIAL         = :CDFILIAL)
                  AND N.CDFILIEMIT      = F.CDFILIAL";

        $params = array("CDALMOXARIFE"=>$cdalmoxarife,
                        "DATARE"=>$datare,
                        "CDLOCALESTOQ"=>$cdlocalestoq,
                        "CDFILIAL"=>$cdfilial,
                        "NRORG"=>$nrorg);
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }

    //procedure
    public function procedureGERA_RE($cdfilial, $identrsaid, $datare, $tipoexpre, $cdalmoxarife, $cdlocalestoq, $iderro){
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'GERA_RE');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $cdfilial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDENTRSAID', Param::PARAM_INPUT, $identrsaid, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DATARE', Param::PARAM_INPUT, $datare, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_TIPOEXPRE', Param::PARAM_INPUT, $tipoexpre, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDALMOXARIFE', Param::PARAM_INPUT, $cdalmoxarife, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDLOCALESTOQ', Param::PARAM_INPUT, $cdlocalestoq, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDERRO', Param::PARAM_INPUT_OUTPUT, $iderro, Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
}